Pillow
======

Pillow is the "friendly PIL fork" by `Alex Clark and Contributors <https://github.com/python-pillow/Pillow/graphs/contributors>`_. PIL is the Python Imaging Library by Fredrik Lundh and Contributors.

.. image:: https://travis-ci.org/python-pillow/Pillow.svg?branch=master
   :target: https://travis-ci.org/python-pillow/Pillow
   :alt: Travis CI build status (Linux)

.. image:: https://travis-ci.org/python-pillow/pillow-wheels.svg?branch=latest
   :target: https://travis-ci.org/python-pillow/pillow-wheels
   :alt: Travis CI build status (OS X)

.. image:: https://img.shields.io/pypi/v/pillow.svg
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/pillow.svg
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Number of PyPI downloads

.. image:: https://coveralls.io/repos/python-pillow/Pillow/badge.svg?branch=master
  :target: https://coveralls.io/r/python-pillow/Pillow?branch=master
   :alt: Code coverage

.. image:: https://landscape.io/github/python-pillow/Pillow/master/landscape.svg
   :target: https://landscape.io/github/python-pillow/Pillow/master
   :alt: Code health

.. toctree::
   :maxdepth: 2

   installation
   guides
   reference/index.rst
   handbook/appendices
   releasenotes/index.rst
   about
   pre-fork-readme

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
